@@ -2,14 +2,18 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2016 - 2018 Kopano b.v.
- * SPDX-FileCopyrightText: Copyright 2020 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020 - 2024 grommunio GmbH
  *
  * grommunio CalDAV backend class which handles calendar related activities.
  */
 
 namespace grommunio\DAV;
 
-class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend implements \Sabre\CalDAV\Backend\SchedulingSupport, \Sabre\CalDAV\Backend\SyncSupport {
+use Sabre\CalDAV\Backend\AbstractBackend;
+use Sabre\CalDAV\Backend\SchedulingSupport;
+use Sabre\CalDAV\Backend\SyncSupport;
+
+class GrommunioCalDavBackend extends AbstractBackend implements SchedulingSupport, SyncSupport {
 	/*
 	 * TODO IMPLEMENT
 	 *
@@ -22,6 +26,8 @@ class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend imple
 	protected $gDavBackend;
 
 	public const FILE_EXTENSION = '.ics';
+	// TODO: implement Task support - Issue: #10
+	public const MESSAGE_CLASSES = ['IPM.Appointment' /* , 'IPM.Note' */];
 	public const CONTAINER_CLASS = 'IPF.Appointment';
 	public const CONTAINER_CLASSES = ['IPF.Appointment', 'IPF.Task'];
 
@@ -33,29 +39,6 @@ class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend imple
 		$this->logger = $glogger;
 	}
 
-	/**
-	 * Publish free/busy information.
-	 *
-	 * Uses the FreeBusyPublish class to publish the information
-	 * about free/busy status.
-	 *
-	 * @param string       $calendarId
-	 * @param mapiresource $calendar
-	 */
-	private function UpdateFB($calendarId, $calendar) {
-		$session = $this->gDavBackend->GetSession();
-		$store = $this->gDavBackend->GetStoreById($calendarId);
-		$weekUnixTime = 7 * 24 * 60 * 60;
-		$start = time() - $weekUnixTime;
-		$range = strtotime("+7 weeks");
-		$storeProps = mapi_getprops($store, [PR_MAILBOX_OWNER_ENTRYID]);
-		if (!isset($storeProps[PR_MAILBOX_OWNER_ENTRYID])) {
-			return;
-		}
-		$pub = new \FreeBusyPublish($session, $store, $calendar, $storeProps[PR_MAILBOX_OWNER_ENTRYID]);
-		$pub->publishFB($start, $range);
-	}
-
 	/**
 	 * Returns a list of calendars for a principal.
 	 *
@@ -100,6 +83,7 @@ class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend imple
 	 */
 	public function createCalendar($principalUri, $calendarUri, array $properties) {
 		$this->logger->trace("principalUri: %s - calendarUri: %s - properties: %s", $principalUri, $calendarUri, $properties);
+
 		// TODO Add displayname
 		return $this->gDavBackend->CreateFolder($principalUri, $calendarUri, static::CONTAINER_CLASS, "");
 	}
@@ -148,7 +132,7 @@ class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend imple
 	 * @return array
 	 */
 	public function getCalendarObjects($calendarId) {
-		$result = $this->gDavBackend->GetObjects($calendarId, static::FILE_EXTENSION);
+		$result = $this->gDavBackend->GetObjects($calendarId, static::FILE_EXTENSION, ['types' => static::MESSAGE_CLASSES]);
 		$this->logger->trace("calendarId: %s found %d objects", $calendarId, count($result));
 
 		return $result;
@@ -333,7 +317,7 @@ class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend imple
 		if (!$retval) {
 			return null;
 		}
-		// $this->UpdateFB($calendarId, $folder);
+
 		return '"' . $retval . '"';
 	}
 
@@ -365,16 +349,16 @@ class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend imple
 		if (!$retval) {
 			return null;
 		}
-		// $this->UpdateFB($calendarId, $folder);
+
 		return '"' . $retval . '"';
 	}
 
 	/**
 	 * Sets data for a calendar item.
 	 *
-	 * @param mixed       $calendarId
-	 * @param MAPIMessage $mapimessage
-	 * @param string      $ics
+	 * @param mixed  $calendarId
+	 * @param mixed  $mapimessage
+	 * @param string $ics
 	 *
 	 * @return null|string
 	 */
@@ -423,7 +407,7 @@ class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend imple
 				$cut2 = strripos($ics, 'END:DAYLIGHT', $lastDaytime) + 14; // strlen('END:DAYLIGHT')
 			}
 
-			$ics = substr($ics, 0, $cutStart) . substr($ics, $cut1, ($cut2 - $cut1)) . substr($ics, $cutEnd);
+			$ics = substr($ics, 0, $cutStart) . substr($ics, $cut1, $cut2 - $cut1) . substr($ics, $cutEnd);
 			$this->logger->trace("newics: %s", $ics);
 		}
 
@@ -596,6 +580,6 @@ class GrommunioCalDavBackend extends \Sabre\CalDAV\Backend\AbstractBackend imple
 	public function getChangesForCalendar($calendarId, $syncToken, $syncLevel, $limit = null) {
 		$this->logger->trace("calendarId: %s - syncToken: %s - syncLevel: %d - limit: %d", $calendarId, $syncToken, $syncLevel, $limit);
 
-		return $this->gDavBackend->Sync($calendarId, $syncToken, static::FILE_EXTENSION, $limit);
+		return $this->gDavBackend->Sync($calendarId, $syncToken, static::FILE_EXTENSION, $limit, ['types' => static::MESSAGE_CLASSES]);
 	}
 }
