@@ -465,7 +465,7 @@ class GrommunioDavBackend {
 					$goid0 = getGoidFromUidZero($id);
 					$restriction[] = [RES_OR, [
 						[RES_PROPERTY, [RELOP => RELOP_EQ, ULPROPTAG => $properties["goid"], VALUE => $goid]],
-						[RES_PROPERTY, [RELOP => RELOP_EQ, ULPROPTAG => $properties["goid"], VALUE => $goid0]]
+						[RES_PROPERTY, [RELOP => RELOP_EQ, ULPROPTAG => $properties["goid"], VALUE => $goid0]],
 					]];
 				}
 				elseif ($extension == GrommunioCardDavBackend::FILE_EXTENSION) {
@@ -489,10 +489,19 @@ class GrommunioDavBackend {
 				$entryid = $rows[0][PR_ENTRYID];
 			}
 		}
+		if (!$entryid) {
+			$this->logger->debug("Try to get entryid from appttsref");
+			$arr = explode(':', $folderId);
+			$sk = $this->syncstate->getSourcekey($arr[1], $id);
+			if ($sk != null) {
+				$this->logger->debug("Found sourcekey from appttsref %s", $sk);
+				$entryid = mapi_msgstore_entryidfromsourcekey($this->GetStoreById($arr[0]), hex2bin($arr[1]), hex2bin($sk));
+			}
+		}
 		if ($entryid) {
 			$mapimessage = mapi_msgstore_openentry($this->GetStoreById($folderId), $entryid);
 			if (!$mapimessage) {
-				$this->logger->warn("Error, unable to open entry id: 0x%X", $entryid, mapi_last_hresult());
+				$this->logger->warn("Error, unable to open entry id: %s 0x%X", bin2hex($entryid), mapi_last_hresult());
 
 				return null;
 			}
@@ -706,7 +715,7 @@ class GrommunioDavBackend {
 		mapi_exportchanges_config($exporter, $stream, SYNC_NORMAL | SYNC_UNICODE, $mapiimporter, null, false, false, $bufferSize);
 		$changesCount = mapi_exportchanges_getchangecount($exporter);
 		$this->logger->debug("Exporter found %d changes, buffer size for mapi_exportchanges_synchronize %d", $changesCount, $bufferSize);
-		while ((is_array(mapi_exportchanges_synchronize($exporter)))) {
+		while (is_array(mapi_exportchanges_synchronize($exporter))) {
 			if ($changesCount > $bufferSize) {
 				$this->logger->info("There were too many changes to be exported in this request. Total changes %d, exported %d.", $changesCount, $phpwrapper->Total());
 
